#
# spec file for package plantuml
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plantuml
Version:        1.2023.13
Release:        1.1
Summary:        Java UML Tool
License:        GPL-3.0-or-later
Group:          Productivity/Publishing/Other
URL:            https://plantuml.com/
Source0:        https://github.com/plantuml/plantuml/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.script
Source10:       http://pdf.plantuml.net/PlantUML_Language_Reference_Guide_en.pdf
Patch0:         build-with-javac-utf8-encoding.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  javapackages-local
BuildRequires:  xmvn-install
Requires:       java >= 1.8.0
Requires:       javapackages-tools
BuildArch:      noarch

%description
PlantUML is a program allowing to draw UML diagrams, using a simple
and human readable text description. It is extremely useful for code
documenting, sketching project architecture during team conversations
and so on.

PlantUML supports the following diagram types
  - sequence diagram
  - use case diagram
  - class diagram
  - activity diagram
  - component diagram
  - state diagram

%package javadoc
Summary:        Javadoc for %{name}
Group:          Productivity/Publishing/Other

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
%patch0 -p1
cp %{SOURCE1} %{name}
cp %{SOURCE10} .

%build
ant

# build javadoc
export CLASSPATH=$(build-classpath ant):plantuml.jar
%javadoc -source 1.8 -encoding UTF-8 -Xdoclint:none -d javadoc $(find src -name "*.java") -windowtitle "PlantUML %{version}"

%install
# Set jar location
%mvn_file net.sourceforge.%{name}:%{name} %{name}
# Configure maven depmap
%mvn_artifact net.sourceforge.%{name}:%{name}:%{version} %{name}.jar
%mvn_install -J javadoc

install -m 755 -d %{buildroot}%{_bindir}/
install -m 755 -d %{buildroot}%{_javadir}
install -m 755 %{name} %{buildroot}%{_bindir}/%{name}

# Install jar file
cp %{name}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

%fdupes %{buildroot}%{_datadir}

%files -f .mfiles
%{_bindir}/plantuml
%{_javadir}/%{name}-%{version}.jar
%license COPYING

%files javadoc -f .mfiles-javadoc
%license COPYING

%changelog
* Thu Dec 14 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2023.13
  * Javadoc improvement.
  * Bug with activity diagram arrows fork.
  * Is is possible to change the milestone icon from a diamond?.
  * Gantt crashes with specific Project start dates.
  * Add support to style timeline fonts for gantt charts.
  * Directory tree listing.
  * Unable to set MaximumWidth style for legend.
  * Wrong note shape in sequence diagram when arrow has only one
    participant.
  * GANTT: How to handle if a resource starts or terminates at a
    specific date.
  * Is it possible to set gantt tasks to be incomplete by default.
  * [Style] Allow LineThickness style for awesome Actor on
    Component/UC/Deployment diagram
  * [Style] Allow multiple style stereotypes for backward element
    on Activity diagram
  * Syntax error on two and more array items in macros
- Update to version 1.2023.12
  * Crash on sample DITAA diagram.
  * Only one transition permitted to State[H] in state diagram.
  * Rendering issue when nesting different elements (partially).
  * force notes to use inner namespaces not global namespace only.
  * ASL distribution no longer includes graphiz.dat.
  * ASL distribution no longer includes OpenIconic SVGs.
- Update to version 1.2023.11
  * [Style] Allow style for backward element on Activity diagram.
  * Sequence diagram: Multi-level nested boxes overlaying each
    other.
  * Using -cypher does not always recognize restricted words.
  * Verticals separators in gantt chart don't appear under certain
    conditions.
  * namespace/package consolidation broke existing remove/restore
    behaviour when using namespace separators.
  * Last label on last elseif branch does not get rendered.
  * no colored border on state start/end.
  * Qualifier labels and associations' lines not correctly drawn
    for qualified associations.
  * Notes on conditionnal elements.
  * Update C4-PlantUML to v2.8.0.
  * Handle @start/@end syntax error better.
- Update to version 1.2023.10
  * Exception error when adding note to timing diagram.
  * Skinparam inconsistencies on class diagram grouping elements.
  * Batik SVG rendering: The attribute "width" of the element
    'rect' is required.
  * skinParam fixCircleLabelOverlapping doesn't work anymore.
  * Using an external style file by pointing to a URL or by using
    a relative file path doesn't work.
  * Add regex, files on Embedded Diagram.
- Update to version 1.2023.9
  * nwdiag possible misbehavior.
  * Replace old ALLOW_PLANTUML_INCLUDE flag by security profile.
    sprite transparent issue.
  * Alpha feature: Directory tree listing.
  * Smetana and ELK: Improve nested elements with last {}
    declaration.
  * [Font][Skinparam or Style] Issues on fall back font (partly).
  * Decimal time values not accepted in parameters or procedures.
- Update to version 1.2023.8
  * First support for regular expression.
  * !theme supports no calculated from path and no stdlib from
    path.
  * Grammar error occurs when specifying full-width digits with
    the "as" keyword in timing diagrams.
* Mon Sep 18 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2023.7
  * Activity: Allow to style SDL stereotype.
  * Activity: Allow post-positioned stereotype style.
  * specifying full-width digits with the "as" keyword in timing
    diagrams.
  * force notes to use inner namespaces not global namespace only.
  * teoz: Support notes on references.
  * Activity diagram, Case statement, arrow label missing.
  * When connecting attributes between object graphs, the
    connection error.
- Update to version 1.2023.6
  * Gantt Milestone with Multiline Text Placement.
  * Start and end nodes can only be styled globally in CSS style.
  * Gantt diagram - Can't close day in the period of opened days.
  * Support notes on references.
  * [gantt] make it possible to color last day.
  * Automatic font color with gradient participant background
    creates UnsupportedOperationException.
  * ConditionStyle InsideDiamond not working for elseif.
  * StateBackgroundColor transparent is not effective.
  * Multible breaks in one repeat.
- Update to version 1.2023.5
  * Error in generating State Diagram.
  * Bug - Crowfoot notation on ERD rendering buggy.
  * Regarding the February update with intermediate
    namespaces.
  * Malformed layout and missing arrows on large amount of
    edges.
  * Smetana and ELK: Improve arrow position and suppress empty
    space.
  * [Class] Note on field is considered unlinked.
  * 'help preprocessors' command is not working.
  * JSON diagram SVG has misplaced arrows when containing
    newlines.
  * [Smetana] Allow notes (or comments) on lines or links.
  * ClassAttributeFont(Style|Size|...) overrides
    ClassFontStyle(Style|Size|...).
  * The command help themes to list all the themes of PlantUML
    seems broken.
  * Note and position not rendering correctly on CheerpJ.
  * Notes linked to messages in Sequence Diagrams.
  * !global $variable ?= "default variable" produces error "a001".
  * Allow only one underscore when escaping.
  * Using end if as an alias for endif in Activity diagrams.
  * Drastic Behavior Change of "as" Parsing with "." (period).
  * nwdiag bug: group causes element to incorrectly connect to
    network
- Update to version 1.2023.4
  * Improve backward compatibility about package and namespace
    simplification.
  * Allow only one underscore when escaping.
  * Using end if as an alias for endif in Activity diagrams.
  * Ability to hide empty fields for object diagrams.
  * Namespace association class connection point outside namespace.
  * Dotted arrow --> is also the close of comment blocks
* Mon Feb 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2023.2
  * package and namespace simplification
  * .repx file generation
  * Cannot set long name arrow label in repeat statement with break
  * together behaves different starting from 1.2023.0
  * Possible regression with class alias declaration
  * The footer is not displayed at the footer
  * latex and package: no perpendicular corners
  * Allow full style on label of Port, Point, Pin
  * Structs do not function properly within a namespace
  * Nwdiag problem with address label position on peer network
  * Update tupadr3 in the stdlib
* Sun Jan 29 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2023.1
  See http://plantuml.com/de/changes for all changes
* Thu Jan 12 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2023.0
  See http://plantuml.com/de/changes for all changes
* Fri Dec 16 2022 Michael Ströder <michael@stroeder.com>
- Update to version 1.2022.14
  See http://plantuml.com/de/changes for all changes
* Sun Sep 18 2022 Markus Ebner <info@ebner-markus.de>
- Update to version 1.2022.7
  See http://plantuml.com/de/changes for all changes
* Mon May 16 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2022.5
  See http://plantuml.com/de/changes for all changes
  * Fix CVE-2022-1379 (bsc#1199557)
- Update patch
  * build-with-javac-utf8-encoding.patch
* Tue Apr 19 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2022.4
  See http://plantuml.com/de/changes for all changes
  * Fix CVE-2022-1231 (bsc#1198591)
* Wed Mar 30 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2022.3
  See http://plantuml.com/de/changes for all changes
* Wed Jan 12 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2022.0
  See http://plantuml.com/de/changes for all changes
* Mon Nov  1 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2021.13
  See http://plantuml.com/de/changes for all changes
* Sun Oct 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2021.12
  See http://plantuml.com/de/changes for all changes
* Thu Sep 16 2021 Markus Ebner <info@ebner-markus.de>
- Update to version 1.2021.10
  See http://plantuml.com/de/changes for all changes
- Add patch:
  * build-with-javac-utf8-encoding.patch
* Sun Apr  4 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2021.4
  See http://plantuml.com/de/changes for all changes
* Tue Mar 23 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2021.3
  See http://plantuml.com/de/changes for all changes
- Drop patch:
  * remove-non-ascii-char.patch (fixed upstream)
* Fri Mar  5 2021 Markus Ebner <info@ebner-markus.de>
- Cleanup
- Update to version 1.2021.1
  See http://plantuml.com/de/changes for all changes
- Build plantuml-javadoc package
- Add patch:
  * remove-non-ascii-char.patch
* Tue Oct 20 2020 Pedro Monreal <pmonreal@suse.com>
- Update link to the pdf manual in the plantuml.xml file
* Mon Oct 12 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.19
  See http://plantuml.com/de/changes for all changes
* Thu Oct  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.18
  See http://plantuml.com/de/changes for all changes
* Sun Sep 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.17
  See http://plantuml.com/de/changes for all changes
* Mon Aug 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.15
  See http://plantuml.com/de/changes for all changes
* Wed Jun 17 2020 Fridrich Strba <fstrba@suse.com>
- Documentation fix: [bsc#1169765]
  * Fetch the PlantUML_Language_Reference_Guide_en.pdf instead of
    a web page that wraps the PDF in javascript feeding ads.
* Wed Jun 17 2020 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- update to version 1.2020.13
  See http://plantuml.com/de/changes for all changes
* Wed Jun 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.12
  See http://plantuml.com/de/changes for all changes
* Sun May 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.9
  See http://plantuml.com/de/changes for all changes
* Tue Apr 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.8
  See http://plantuml.com/de/changes for all changes
* Mon Apr  6 2020 Andreas Hasenkopf <ahasenkopf@suse.com>
- Added requirement 'dejavu-fonts'
* Sun Apr  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2020.6
  See http://plantuml.com/de/changes for all changes
* Wed Dec 11 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.13
  See http://plantuml.com/de/changes for all changes
* Wed Nov  6 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.12
  See http://plantuml.com/de/changes for all changes
* Sun Sep 22 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.11
  See http://plantuml.com/de/changes for all changes
* Mon Sep 16 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.10
  See http://plantuml.com/de/changes for all changes
* Tue Aug 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.9
  See http://plantuml.com/de/changes for all changes
* Mon May 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2019.6
  See http://plantuml.com/de/changes for all changes
* Mon Apr 29 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream version 1.2019.4
- Restore original changelog entries
* Fri Feb  8 2019 ahasenkopf@suse.com
- Fixed package internal issues
* Fri Jan 11 2019 ahasenkopf@suse.com
- First commit for version 1.2018.14
* Tue Sep  4 2018 mardnh@gmx.de
- Update to new upstream version 1.2018.10
- Run spec-cleander
* Tue Aug 25 2015 michiel.vanderwulp@gmail.com
- Improve the man page
* Thu Aug 20 2015 michiel.vanderwulp@gmail.com
- Update to PlantUML 8029
* Fri Jun  5 2015 michiel.vanderwulp@gmail.com
- Update to PlantUML 8025
* Sun Sep  4 2011 toms@suse.de
- Initial version 7177
